//
//  ItemPersonView.swift
//  Jel
//
//  Created by zerocool on 1/13/24.
//

import SwiftUI
import JellyfinKit
import ExpandableText

struct ItemPersonViewItemsRow: View {
  var items: [BaseItemDto]
  
  var body: some View {
    ScrollView(.horizontal) {
      LazyHStack {
        ForEach(items) {item in
          NavigationLink {
            ItemView(item: item)
          } label: {
            ItemIconView(item: item, width: 150)
              .showCaption()
              .setAspectRatio(item.primaryImageAspectRatio ?? 0.6)
              .padding()
          }
          .buttonStyle(PlainButtonStyle())
        }
      }
      .padding(.horizontal)
    }
  }
}

struct ItemPersonView: View {
  @EnvironmentObject var jellyfinClient: JellyfinClientController
  
  var item: BaseItemDto
  
  @State var items: [BaseItemDto]?
  
  var body: some View {
    VStack(alignment: .leading) {
      Text(item.name ?? "---")
        .font(.title)
        .padding()
      
      if let overview = item.overview {
        ExpandableText(overview)
          .lineLimit(8)
          .padding([.horizontal, .bottom])
      }
      
      if let items = items {
        // TODO: Extract to view to maintain DRY
        let movies = items.filter({$0.type == .movie})
        if movies.count > 0 {
          Text("Movies")
            .font(.title2)
            .padding(.horizontal)
          ItemPersonViewItemsRow(items: movies)
        }
        
        let shows = items.filter({$0.type == .series})
        if shows.count > 0 {
          Text("Shows")
            .font(.title2)
            .padding(.horizontal)
          ItemPersonViewItemsRow(items: shows)
        }
      }
    }
    .onAppear {
      Task {
        let parameters = Paths.GetItemsParameters(
          isRecursive: true,
          personIDs: [item.id ?? ""]
        )
        let request = Paths.getItems(parameters: parameters)
        
        do {
          let res = try await jellyfinClient.send(request)
          items = res.value.items ?? []
          print(items![0])
        } catch {}
      }
    }
  }
}

//#Preview {
//    ItemPersonView()
//}
